@@ -80,7 +80,9 @@ fi
 
 
 VERSION=$("$CONTRIB"/print_electrum_version.py)
+APK_VERSION=$("$CONTRIB"/print_electrum_version.py APK_VERSION)
 info "VERSION: $VERSION"
+info "APK_VERSION: $APK_VERSION"
 REV=$(git describe --tags)
 info "REV: $REV"
 COMMIT=$(git rev-parse HEAD)
@@ -145,28 +147,29 @@ else
 fi
 
 # android
-apk1="Electrum-$VERSION.0-armeabi-v7a-release.apk"
-apk1_unsigned="Electrum-$VERSION.0-armeabi-v7a-release-unsigned.apk"
-apk2="Electrum-$VERSION.0-arm64-v8a-release.apk"
-apk2_unsigned="Electrum-$VERSION.0-arm64-v8a-release-unsigned.apk"
-apk3="Electrum-$VERSION.0-x86_64-release.apk"
-apk3_unsigned="Electrum-$VERSION.0-x86_64-release-unsigned.apk"
-if test -f "dist/$apk1"; then
-    info "file exists: $apk1"
-else
-    if [ ! -z "$RELEASEMANAGER" ] ; then
-        ./contrib/android/build.sh qml all release $password
+apk1="Electrum-$APK_VERSION-armeabi-v7a-release.apk"
+apk2="Electrum-$APK_VERSION-arm64-v8a-release.apk"
+apk3="Electrum-$APK_VERSION-x86_64-release.apk"
+for arch in armeabi-v7a arm64-v8a x86_64
+do
+    apk="Electrum-$APK_VERSION-$arch-release.apk"
+    apk_unsigned="Electrum-$APK_VERSION-$arch-release-unsigned.apk"
+    if test -f "dist/$apk"; then
+        info "file exists: $apk"
     else
-        ./contrib/android/build.sh qml all release-unsigned
-        mv "dist/$apk1_unsigned" "dist/$apk1"
-        mv "dist/$apk2_unsigned" "dist/$apk2"
-        mv "dist/$apk3_unsigned" "dist/$apk3"
+        info "file does not exists: $apk"
+        if [ ! -z "$RELEASEMANAGER" ] ; then
+            ./contrib/android/build.sh qml $arch release $password
+        else
+            ./contrib/android/build.sh qml $arch release-unsigned
+            mv "dist/$apk_unsigned" "dist/$apk"
+        fi
     fi
-fi
+done
 
 # the macos binary is built on a separate machine.
 # the file that needs to be copied over is the codesigned release binary (regardless of builder role)
-dmg=electrum-$VERSION.dmg
+dmg="electrum-$VERSION.dmg"
 if ! test -f "dist/$dmg"; then
     if [ ! -z "$RELEASEMANAGER" ] ; then  # RM
         fail "dmg is missing, aborting. Please build and codesign the dmg on a mac and copy it over."
@@ -259,6 +262,18 @@ else
 
     cd "$PROJECT_ROOT"
 
+    # check we have each binary
+    test -f "$PROJECT_ROOT/dist/$tarball"    || fail "tarball not found among built files"
+    test -f "$PROJECT_ROOT/dist/$srctarball" || fail "srctarball not found among built files"
+    test -f "$PROJECT_ROOT/dist/$appimage"   || fail "appimage not found among built files"
+    test -f "$PROJECT_ROOT/dist/$win1"       || fail "win1 not found among built files"
+    test -f "$PROJECT_ROOT/dist/$win2"       || fail "win2 not found among built files"
+    test -f "$PROJECT_ROOT/dist/$win3"       || fail "win3 not found among built files"
+    test -f "$PROJECT_ROOT/dist/$apk1"       || fail "apk1 not found among built files"
+    test -f "$PROJECT_ROOT/dist/$apk2"       || fail "apk2 not found among built files"
+    test -f "$PROJECT_ROOT/dist/$apk3"       || fail "apk3 not found among built files"
+    test -f "$PROJECT_ROOT/dist/$dmg"        || fail "dmg not found among built files"
+
     if [ $REV != $VERSION ]; then
         fail "versions differ, not uploading"
     fi
